@@ -34,67 +34,71 @@
 #'
 #' @export
 #'
-string_replacements <- function(input, replace_mapping = "default", tolower = FALSE, toupper = FALSE) {
-  res <- input
-  replaceme <- list(
-    # "replace_this" = "with_this",
-    "(" = "",
-    ")" = "",
-    "{" = "",
-    "}" = "",
-    "." = "",
-    " " = "_",
-    "=" = "",
-    "__" = "_"
-  )
-
-  if (is.list(replace_mapping)) {
-    ## Use the mapping handed over to the function:
-    replaceme <- replace_mapping
-  } else if (replace_mapping == "default") {
-    replaceme <- replaceme
-  } else {
-    DIZutils::feedback(
-      print_this = paste0(
-        "There is something handed over as `replace_mapping`",
-        " which is not a list. Using default replacement instead."
-      ),
-      type = "Warning",
-      findme = "7c9d35cd88"
+string_replacements <-
+  function(input,
+           replace_mapping = "default",
+           tolower = FALSE,
+           toupper = FALSE) {
+    res <- input
+    replaceme <- list(
+      # "replace_this" = "with_this",
+      "(" = "",
+      ")" = "",
+      "{" = "",
+      "}" = "",
+      "." = "",
+      " " = "_",
+      "=" = "",
+      "__" = "_"
     )
-  }
 
-  iteration <- 0
-  finished_changing <- FALSE
-  while (iteration < 1000 && !finished_changing) {
-    finished_changing <- TRUE
-    for (replace_this in names(replaceme)) {
-      res <-
-        gsub(
-          pattern = replace_this,
-          replacement = replaceme[[replace_this]],
-          x = res,
-          fixed = TRUE
-        )
+    if (is.list(replace_mapping)) {
+      ## Use the mapping handed over to the function:
+      replaceme <- replace_mapping
+    } else if (replace_mapping == "default") {
+      replaceme <- replaceme
+    } else {
+      DIZutils::feedback(
+        print_this = paste0(
+          "There is something handed over as `replace_mapping`",
+          " which is not a list. Using default replacement instead."
+        ),
+        type = "Warning",
+        findme = "7c9d35cd88"
+      )
     }
-    for (replace_this in names(replaceme)) {
-      ## Check if there is still something left to change:
-      if (grepl(pattern = replace_this,
-                x = res,
-                fixed = TRUE)) {
-        ## There is a character left which needs to be changed,
-        ## so this loop will be computed again.
-        finished_changing <- FALSE
+
+    iteration <- 0
+    finished_changing <- FALSE
+    while (iteration < 1000 && !finished_changing) {
+      finished_changing <- TRUE
+      for (replace_this in names(replaceme)) {
+        res <-
+          gsub(
+            pattern = replace_this,
+            replacement = replaceme[[replace_this]],
+            x = res,
+            fixed = TRUE
+          )
       }
+      for (replace_this in names(replaceme)) {
+        ## Check if there is still something left to change:
+        if (grepl(pattern = replace_this,
+                  x = res,
+                  fixed = TRUE)) {
+          ## There is a character left which needs to be changed,
+          ## so this loop will be computed again.
+          finished_changing <- FALSE
+        }
+      }
+      iteration <- iteration + 1
     }
-    iteration <- iteration + 1
-  }
 
-  if (tolower) {
-    res <- tolower(res)
-  } else if (toupper) {
-    res <- toupper(res)
-  }
+    if (tolower) {
+      res <- tolower(res)
+    } else if (toupper) {
+      res <- toupper(res)
+    }
 
-  return(res)
-}
+    return(res)
+  }
